@@ -1,8 +1,11 @@
 //! Handles the parsing of the query string
 
+use std::path::PathBuf;
 use std::rc::Rc;
 use std::str::FromStr;
 
+use directories::UserDirs;
+
 use crate::expr::Expr;
 use crate::field::Field;
 use crate::function::Function;
@@ -15,8 +18,8 @@ use crate::query::Query;
 use crate::query::Root;
 use crate::query::TraversalMode::{Bfs, Dfs};
 use crate::query::{OutputFormat, RootOptions};
-use directories::UserDirs;
-use std::path::PathBuf;
+#[cfg(not(feature = "git"))]
+use crate::util::error_message;
 
 pub struct Parser {
     lexems: Vec<Lexem>,
@@ -197,7 +200,7 @@ impl Parser {
                 let lexem = self.next_lexem();
                 match lexem {
                     Some(ref lexem) => match lexem {
-                        Lexem::String(ref s) | Lexem::RawString(ref s) => match mode {
+                        Lexem::String(s) | Lexem::RawString(s) => match mode {
                             RootParsingMode::From | RootParsingMode::Comma => {
                                 path = s.to_string();
                                 if path.starts_with("~") {
@@ -211,6 +214,18 @@ impl Parser {
                                 mode = RootParsingMode::Root;
                             }
                             RootParsingMode::Root => {
+                                if s.to_lowercase() == "group" {
+                                    if let Some(Lexem::By) = self.next_lexem() {
+                                        self.drop_lexem();
+                                        self.drop_lexem();
+
+                                        if !path.is_empty() {
+                                            roots.push(Root::new(path, root_options));
+                                        }
+                                        break;
+                                    }
+                                }
+                                
                                 self.drop_lexem();
                                 match self.parse_root_options() {
                                     Some(options) => root_options = options,
@@ -258,6 +273,7 @@ impl Parser {
     }
 
     fn parse_root_options(&mut self) -> Option<RootOptions> {
+        #[derive(Debug)]
         enum RootParsingMode {
             Unknown,
             Options,
@@ -281,7 +297,7 @@ impl Parser {
             let lexem = self.next_lexem();
             match lexem {
                 Some(ref lexem) => match lexem {
-                    Lexem::String(ref s) | Lexem::RawString(ref s) => match mode {
+                    Lexem::String(s) | Lexem::RawString(s) => match mode {
                         RootParsingMode::Unknown | RootParsingMode::Options => {
                             let s = s.to_ascii_lowercase();
                             if s == "mindepth" {
@@ -295,8 +311,17 @@ impl Parser {
                                 symlinks = true;
                                 mode = RootParsingMode::Options;
                             } else if s.starts_with("git") {
-                                gitignore = Some(true);
-                                mode = RootParsingMode::Options;
+                                #[cfg(feature = "git")]
+                                {
+                                    gitignore = Some(true);
+                                    mode = RootParsingMode::Options;
+                                }
+                                #[cfg(not(feature = "git"))]
+                                {
+                                    error_message("parser", "git support is not enabled");
+                                    self.drop_lexem();
+                                    break;
+                                }
                             } else if s.starts_with("hg") {
                                 hgignore = Some(true);
                                 mode = RootParsingMode::Options;
@@ -385,9 +410,10 @@ impl Parser {
     }
 
     fn is_root_option_keyword(s: &str) -> bool {
-        s.to_ascii_lowercase() == "depth"
-            || s.to_ascii_lowercase() == "mindepth"
-            || s.to_ascii_lowercase() == "maxdepth"
+        let s = s.to_ascii_lowercase();
+        s == "depth"
+            || s == "mindepth"
+            || s == "maxdepth"
             || s.starts_with("arc")
             || s.starts_with("sym")
             || s.starts_with("git")
@@ -1373,4 +1399,19 @@ mod tests {
 
         assert_eq!(query.expr, query2.expr);
     }
+    
+    #[test]
+    fn query_with_dfs() {
+        let query = "select name from /test dfs group by mime";
+        let mut p = Parser::new();
+        let query = p.parse(vec![query.to_string()], false).unwrap();
+        
+        assert_eq!(
+            query.roots,
+            vec![Root::new(
+                String::from("/test"),
+                RootOptions::from(0, 0, false, false, None, None, None, Dfs, false)
+            ),]
+        );
+    }
 }
