@@ -14,6 +14,7 @@ use std::path::{Path, PathBuf};
 use std::rc::Rc;
 
 use chrono::{DateTime, Local};
+#[cfg(feature = "git")]
 use git2::Repository;
 use lscolors::{LsColors, Style};
 use mp3_metadata::MP3Metadata;
@@ -233,7 +234,7 @@ impl<'a> Searcher<'a> {
 
     /// Searches directories based on configured query and outputs results to stdout.
     pub fn list_search_results(&mut self) -> io::Result<()> {
-        let current_dir = std::env::current_dir().unwrap();
+        let current_dir = std::env::current_dir()?;
 
         if let Err(e) = self.results_writer.write_header(&mut std::io::stdout()) {
             if e.kind() == ErrorKind::BrokenPipe {
@@ -241,6 +242,8 @@ impl<'a> Searcher<'a> {
             }
         }
 
+        let start_time = std::time::Instant::now();
+
         let mut roots = vec![];
 
         // ======== Process each root specified in the query =========
@@ -383,6 +386,7 @@ impl<'a> Searcher<'a> {
                 0,
                 search_archives,
                 apply_gitignore,
+                #[cfg(feature = "git")]
                 Repository::discover(&root_dir).ok().as_ref(),
                 apply_hgignore,
                 apply_dockerignore,
@@ -390,6 +394,8 @@ impl<'a> Searcher<'a> {
                 true,
             );
         }
+        
+        let compute_time = std::time::Instant::now();
 
         // ======== Compute results =========
         if self.has_aggregate_column() {
@@ -405,9 +411,11 @@ impl<'a> Searcher<'a> {
                     .map(|f| f.to_string())
                     .collect();
                 let buffer_partitions = self.partitioned_output_buffer.clone();
-
+                let buffer_partitions = buffer_partitions.iter().collect::<Vec<_>>();                 
+                
+                let mut results = vec![];
+                
                 buffer_partitions.iter().for_each(|f| {
-                    let mut buf = WritableBuffer::new();
                     let mut items: Vec<(String, String)> = Vec::new();
 
                     let mut file_map = HashMap::new();
@@ -430,10 +438,63 @@ impl<'a> Searcher<'a> {
                         items.push((field_name, record));
                     }
 
-                    let _ = self.results_writer.write_row(&mut buf, items);
+                    results.push(items);
+                });
 
+                if !self.query.ordering_fields.is_empty() {
+                    let ordering_fields = self
+                        .query
+                        .ordering_fields
+                        .iter()
+                        .map(|f| f.to_string().to_lowercase())
+                        .collect::<Vec<String>>();
+                    let directions = self.query.ordering_asc.clone();
+                    let sorting_indices = ordering_fields
+                        .iter()
+                        .map(|f| {
+                            self.query
+                                .fields
+                                .iter()
+                                .map(|f| f.to_string().to_lowercase())
+                                .position(|g| &g == f)
+                                .unwrap_or(0)
+                        })
+                        .collect::<Vec<usize>>();
+
+                    results.sort_by(|a, b| {
+                        sorting_indices
+                            .iter()
+                            .enumerate()
+                            .map(|(idx, i)| {
+                                if let Some(a) = a.get(*i) {
+                                    if let Ok(a) = a.1.parse::<i64>() {
+                                        if let Some(b) = b.get(*i) {
+                                            if let Ok(b) = b.1.parse::<i64>() {
+                                                return if directions[idx] { 
+                                                    a.cmp(&b) 
+                                                } else { 
+                                                    b.cmp(&a) 
+                                                };
+                                            }
+                                        }
+                                    }
+                                }
+                                if directions[idx] { 
+                                    a.get(*i).unwrap().1.cmp(&b.get(*i).unwrap().1) 
+                                } else { 
+                                    b.get(*i).unwrap().1.cmp(&a.get(*i).unwrap().1) 
+                                } 
+                            })
+                            .find(|r| *r != std::cmp::Ordering::Equal)
+                            .unwrap_or(std::cmp::Ordering::Equal)
+                    });
+                }
+
+                results.iter().for_each(|items| {
+                    let mut buf = WritableBuffer::new();
+                    let _ = self.results_writer.write_row(&mut buf, items.to_owned());
                     let _ = write!(std::io::stdout(), "{}", String::from(buf));
-                })
+                });
             } else {
                 let mut buf = WritableBuffer::new();
                 let mut items: Vec<(String, String)> = Vec::new();
@@ -484,6 +545,14 @@ impl<'a> Searcher<'a> {
 
         self.results_writer.write_footer(&mut std::io::stdout())?;
 
+        let completion_time = std::time::Instant::now();
+        
+        if self.config.debug {
+            eprintln!("Search: {}ms\nCompute: {}ms", 
+                      compute_time.duration_since(start_time).as_millis(), 
+                      completion_time.duration_since(compute_time).as_millis());
+        }
+        
         Ok(())
     }
 
@@ -497,6 +566,7 @@ impl<'a> Searcher<'a> {
         root_depth: u32,
         search_archives: bool,
         apply_gitignore: bool,
+        #[cfg(feature = "git")]
         git_repository: Option<&Repository>,
         apply_hgignore: bool,
         apply_dockerignore: bool,
@@ -547,32 +617,42 @@ impl<'a> Searcher<'a> {
                     match entry {
                         Ok(entry) => {
                             let mut path = entry.path();
-                            let mut canonical_path = path.clone();
+                            let pass_ignores = if apply_gitignore || apply_hgignore || apply_dockerignore {
+                                let mut canonical_path = path.clone();
 
-                            if apply_gitignore || apply_hgignore || apply_dockerignore {
-                                if let Ok(canonicalized) = crate::util::canonical_path(&path) {
-                                    canonical_path = PathBuf::from(canonicalized);
+                                if apply_gitignore || apply_hgignore || apply_dockerignore {
+                                    if let Ok(canonicalized) = crate::util::canonical_path(&path) {
+                                        canonical_path = PathBuf::from(canonicalized);
+                                    }
                                 }
-                            }
 
-                            // Check the path against the filters
-                            let pass_gitignore = !apply_gitignore
-                                || !(git_repository.is_some() && 
+                                // Check the path against the filters
+                                #[cfg(feature = "git")]
+                                let pass_gitignore = !apply_gitignore
+                                    || !(git_repository.is_some() &&
                                     git_repository.unwrap().is_path_ignored(&path)
                                         .unwrap_or(false));
-                            let pass_hgignore = !apply_hgignore
-                                || !matches_hgignore_filter(
+                                #[cfg(not(feature = "git"))]
+                                let pass_gitignore = true;
+
+                                let pass_hgignore = !apply_hgignore
+                                    || !matches_hgignore_filter(
                                     &self.hgignore_filters,
                                     canonical_path.to_string_lossy().as_ref(),
                                 );
-                            let pass_dockerignore = !apply_dockerignore
-                                || !matches_dockerignore_filter(
+                                let pass_dockerignore = !apply_dockerignore
+                                    || !matches_dockerignore_filter(
                                     &self.dockerignore_filters,
                                     canonical_path.to_string_lossy().as_ref(),
                                 );
 
+                                pass_gitignore && pass_hgignore && pass_dockerignore
+                            } else {
+                                true
+                            };                            
+
                             // If the path passes the filters, process it
-                            if pass_gitignore && pass_hgignore && pass_dockerignore {
+                            if pass_ignores {
                                 if min_depth == 0 || depth >= min_depth {
                                     let checked = self.check_file(&entry, &None)?;
                                     if !checked {
@@ -622,7 +702,9 @@ impl<'a> Searcher<'a> {
 
                                         if ok && self.ok_to_visit_dir(&entry, file_type) {
                                             if traversal_mode == TraversalMode::Dfs {
+                                                #[cfg(feature = "git")]
                                                 let repo;
+                                                #[cfg(feature = "git")]
                                                 let git_repository = match git_repository {
                                                     Some(repo) => Some(repo),
                                                     None if apply_gitignore => {
@@ -638,6 +720,7 @@ impl<'a> Searcher<'a> {
                                                     base_depth,
                                                     search_archives,
                                                     apply_gitignore,
+                                                    #[cfg(feature = "git")]
                                                     git_repository,
                                                     apply_hgignore,
                                                     apply_dockerignore,
@@ -679,7 +762,9 @@ impl<'a> Searcher<'a> {
         if traversal_mode == Bfs && process_queue {
             while !self.dir_queue.is_empty() {
                 let path = self.dir_queue.pop_front().unwrap();
+                #[cfg(feature = "git")]
                 let repo;
+                #[cfg(feature = "git")]
                 let git_repository = match git_repository {
                     Some(repo) => Some(repo),
                     None if apply_gitignore => {
@@ -695,6 +780,7 @@ impl<'a> Searcher<'a> {
                     base_depth,
                     search_archives,
                     apply_gitignore,
+                    #[cfg(feature = "git")]
                     git_repository,
                     apply_hgignore,
                     apply_dockerignore,
@@ -743,17 +829,23 @@ impl<'a> Searcher<'a> {
         buffer_data: Option<&Vec<HashMap<String, String>>>,
         column_expr: &Expr,
     ) -> Variant {
+        let column_expr_str = column_expr.to_string();
+
+        if file_map.contains_key(&column_expr_str) {
+            return Variant::from_string(&file_map[&column_expr_str]);
+        }
+        
         if let Some(ref _function) = column_expr.function {
             let result =
                 self.get_function_value(entry, file_info, file_map, buffer_data, column_expr);
-            file_map.insert(column_expr.to_string(), result.to_string());
+            file_map.insert(column_expr_str, result.to_string());
             return result;
         }
 
         if let Some(ref field) = column_expr.field {
             if entry.is_some() {
                 let result = self.get_field_value(entry.unwrap(), file_info, field);
-                file_map.insert(column_expr.to_string(), result.to_string());
+                file_map.insert(column_expr_str, result.to_string());
                 return result;
             } else if let Some(val) = file_map.get(&field.to_string()) {
                 return Variant::from_string(val);
@@ -777,7 +869,7 @@ impl<'a> Searcher<'a> {
                     let right_result =
                         self.get_column_expr_value(entry, file_info, file_map, buffer_data, right);
                     result = op.calc(&left_result, &right_result);
-                    file_map.insert(column_expr.to_string(), result.to_string());
+                    file_map.insert(column_expr_str, result.to_string());
                 } else {
                     result = left_result;
                 }
@@ -818,7 +910,7 @@ impl<'a> Searcher<'a> {
                 buffer_key,
                 &column_expr.val,
             );
-            return Variant::from_string(&aggr_result);
+            Variant::from_string(&aggr_result)
         } else {
             let function_arg =
                 self.get_column_expr_value(entry, file_info, file_map, buffer_data, left_expr);
@@ -839,7 +931,7 @@ impl<'a> Searcher<'a> {
             );
             file_map.insert(column_expr.to_string(), result.to_string());
 
-            return result;
+            result
         }
     }
 
@@ -879,7 +971,7 @@ impl<'a> Searcher<'a> {
 
         match field {
             Field::Name => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_string(&format!(
                         "[{}] {}",
                         entry.file_name().to_string_lossy(),
@@ -894,7 +986,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::Extension => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_string(&format!(
                         "[{}] {}",
                         entry.file_name().to_string_lossy(),
@@ -909,7 +1001,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::Path => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_string(&format!(
                         "[{}] {}",
                         entry.path().to_string_lossy(),
@@ -921,7 +1013,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::AbsPath => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_string(&format!(
                         "[{}] {}",
                         entry.path().to_string_lossy(),
@@ -936,7 +1028,7 @@ impl<'a> Searcher<'a> {
             },
             Field::Directory => {
                 let file_path = match file_info {
-                    Some(ref file_info) => file_info.name.clone(),
+                    Some(file_info) => file_info.name.clone(),
                     _ => entry.path().to_string_lossy().to_string(),
                 };
                 let pb = PathBuf::from(file_path);
@@ -946,7 +1038,7 @@ impl<'a> Searcher<'a> {
             }
             Field::AbsDir => {
                 let file_path = match file_info {
-                    Some(ref file_info) => file_info.name.clone(),
+                    Some(file_info) => file_info.name.clone(),
                     _ => entry.path().to_string_lossy().to_string(),
                 };
                 let pb = PathBuf::from(file_path);
@@ -961,7 +1053,7 @@ impl<'a> Searcher<'a> {
                 }
             }
             Field::Size => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_int(file_info.size as i64);
                 }
                 _ => {
@@ -974,7 +1066,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::FormattedSize => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_string(&format_filesize(
                         file_info.size,
                         self.config
@@ -999,7 +1091,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::IsDir => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_bool(
                         file_info.name.ends_with('/') || file_info.name.ends_with('\\'),
                     );
@@ -1014,7 +1106,7 @@ impl<'a> Searcher<'a> {
                 }
             },
             Field::IsFile => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_bool(!file_info.name.ends_with('/'));
                 }
                 _ => {
@@ -1119,7 +1211,7 @@ impl<'a> Searcher<'a> {
                 return Variant::empty(VariantType::String);
             }
             Field::Mode => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     if let Some(mode) = file_info.mode {
                         return Variant::from_string(&mode::format_mode(mode));
                     }
@@ -1246,7 +1338,7 @@ impl<'a> Searcher<'a> {
                 );
             }
             Field::IsHidden => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_bool(is_hidden(&file_info.name, &None, true));
                 }
                 _ => {
@@ -1333,7 +1425,7 @@ impl<'a> Searcher<'a> {
                 }
             }
             Field::Modified => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     if let Some(file_info_modified) = &file_info.modified {
                         let dt = to_local_datetime(file_info_modified);
                         return Variant::from_datetime(dt);
@@ -1385,7 +1477,7 @@ impl<'a> Searcher<'a> {
                 return Variant::from_bool(is_shebang(&entry.path()));
             }
             Field::IsEmpty => match file_info {
-                Some(ref file_info) => {
+                Some(file_info) => {
                     return Variant::from_bool(file_info.size == 0);
                 }
                 _ => {
@@ -1790,7 +1882,7 @@ impl<'a> Searcher<'a> {
         mode_func_i32: &dyn Fn(u32) -> bool,
     ) -> Variant {
         match file_info {
-            Some(ref file_info) => {
+            Some(file_info) => {
                 if let Some(mode) = file_info.mode {
                     return Variant::from_bool(mode_func_i32(mode));
                 }
