@@ -488,8 +488,8 @@ pub fn format_absolute_path(path_buf: &Path) -> String {
 
 pub fn get_metadata(entry: &DirEntry, follow_symlinks: bool) -> Option<Metadata> {
     let metadata = match follow_symlinks {
-        false => symlink_metadata(entry.path()),
-        true => fs::metadata(entry.path()),
+        false => entry.metadata(),
+        true => symlink_metadata(entry.path()),
     };
 
     if let Ok(metadata) = metadata {
@@ -621,7 +621,7 @@ pub fn is_hidden(file_name: &str, metadata: &Option<Metadata>, archive_mode: boo
 
     #[cfg(windows)]
     {
-        if let Some(ref metadata) = metadata {
+        if let Some(metadata) = metadata {
             return mode::get_mode(metadata).contains("Hidden");
         }
     }
